@@ -8,11 +8,7 @@ import IPython
 from pygments import highlight, lexers, formatters
 
 from pymobiledevice3 import usbmux
-
-
-class ConnectionFailedException(Exception):
-    pass
-
+from pymobiledevice3.exceptions import ConnectionFailedError
 
 SHELL_USAGE = """
 # This shell allows you to communicate directly with every service layer behind the lockdownd daemon.
@@ -27,7 +23,7 @@ print(client.recv_plist())
 client.send(b"hello")
 
 # and view the result
-print(client.recv_exact(20))
+print(client.recvall(20))
 """
 
 
@@ -48,10 +44,11 @@ class ServiceConnection(object):
                 if connected_device.serial == udid:
                     target_device = connected_device
                     break
+
         try:
             socket = mux.connect(target_device, port)
-        except:
-            raise ConnectionFailedException(f'Connection to device port {port} failed')
+        except usbmux.MuxError:
+            raise ConnectionFailedError(f'Connection to device port {port} failed')
 
         return ServiceConnection(socket)
 
@@ -62,42 +59,44 @@ class ServiceConnection(object):
         self.socket.close()
 
     def recv(self, length=4096):
-        data = self.socket.recv(length)
-        return data
+        """ socket.recv() normal behavior. attempt to receive a single chunk """
+        return self.socket.recv(length)
 
-    def send(self, data):
+    def sendall(self, data):
         self.socket.sendall(data)
 
-    def send_request(self, data):
+    def send_recv_plist(self, data):
         self.send_plist(data)
         return self.recv_plist()
 
-    def recv_exact(self, l):
-        data = b""
-        while l > 0:
-            d = self.recv(l)
+    def recvall(self, size):
+        data = b''
+        while size > 0:
+            d = self.recv(size)
             if not d or len(d) == 0:
                 break
             data += d
-            l -= len(d)
+            size -= len(d)
         return data
 
-    def recv_raw(self):
-        l = self.recv_exact(4)
-        if not l or len(l) != 4:
+    def recv_prefixed(self):
+        """ receive a data block prefixed with a u32 length field """
+        response = self.recvall(4)
+        if not response or len(response) != 4:
             return
-        l = struct.unpack(">L", l)[0]
-        return self.recv_exact(l)
+        response = struct.unpack('>L', response)[0]
+        return self.recvall(response)
 
-    def send_raw(self, data):
+    def send_prefixed(self, data):
+        """ send a data block prefixed with a u32 length field """
         if isinstance(data, str):
             data = data.encode()
-        hdr = struct.pack(">L", len(data))
-        msg = b"".join([hdr, data])
-        return self.send(msg)
+        hdr = struct.pack('>L', len(data))
+        msg = b''.join([hdr, data])
+        return self.sendall(msg)
 
     def recv_plist(self):
-        payload = self.recv_raw()
+        payload = self.recv_prefixed()
         if not payload:
             return
         bplist_header = b'bplist00'
@@ -113,8 +112,8 @@ class ServiceConnection(object):
 
     def send_plist(self, d):
         payload = plistlib.dumps(d)
-        l = struct.pack(">L", len(payload))
-        return self.send(l + payload)
+        message = struct.pack(">L", len(payload))
+        return self.sendall(message + payload)
 
     def ssl_start(self, keyfile, certfile):
         self.socket = ssl.wrap_socket(self.socket, keyfile, certfile, ssl_version=ssl.PROTOCOL_TLSv1)
