@@ -13,19 +13,19 @@ class NotificationProxyService(object):
 
     def notify_post(self, name):
         """ Send notification to the device's notification_proxy. """
-        self.service.send_plist({"Command": "PostNotification",
-                                 "Name": name})
+        self.service.send_plist({'Command': 'PostNotification',
+                                 'Name': name})
 
-        self.service.send_plist({"Command": "Shutdown"})
+        self.service.send_plist({'Command': 'Shutdown'})
         res = self.service.recv_plist()
-        if res.get("Command", None) != "ProxyDeath":
+        if res.get('Command', None) != 'ProxyDeath':
             raise Exception(f'invalid response: {res}')
 
     def notify_register_dispatch(self, name):
         """ Tells the device to send a notification on the specified event. """
-        self.logger.info("Observing %s", name)
-        self.service.send_plist({"Command": "ObserveNotification",
-                                 "Name": name})
+        self.logger.info('Observing %s', name)
+        self.service.send_plist({'Command': 'ObserveNotification',
+                                 'Name': name})
 
     def receive_notification(self):
         while True:
